@@ -2,8 +2,9 @@ use 5.16.0;
 
 package Map::Metro::Plugin::Map::Copenhagen;
 
-our $VERSION = '0.2006'; # VERSION
 # ABSTRACT: Map::Metro map for Copenhagen
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.2007';
 
 use Moose;
 with 'Map::Metro::Plugin::Map';
@@ -32,22 +33,21 @@ Map::Metro::Plugin::Map::Copenhagen - Map::Metro map for Copenhagen
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.16+-brightgreen.svg" alt="Requires Perl 5.16+" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro-Copenhagen"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Copenhagen.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-69.2%-red.svg" alt="coverage 69.2%" /></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.16+-blue.svg" alt="Requires Perl 5.16+" />
+<a href="https://travis-ci.org/Csson/p5-Map-Metro-Copenhagen"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Copenhagen.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Map-Metro-Plugin-Map-Copenhagen-0.2007"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Map-Metro-Plugin-Map-Copenhagen/0.2007" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro-Plugin-Map-Copenhagen%200.2007"><img src="http://badgedepot.code301.com/badge/cpantesters/Map-Metro-Plugin-Map-Copenhagen/0.2007" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-69.2%-red.svg" alt="coverage 69.2%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.16+](https://img.shields.io/badge/perl-5.16+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro-Copenhagen.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro-Copenhagen) ![coverage 69.2%](https://img.shields.io/badge/coverage-69.2%-red.svg)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.2006, released 2016-01-21.
+Version 0.2007, released 2019-10-30.
 
 =head1 SYNOPSIS
 
@@ -66,7 +66,7 @@ This map includes:
 
 =item *
 
-Both lines of the Copenhagen metro (L<wikipedia|https://en.wikipedia.org/wiki/Copenhagen_metro>)
+All three current lines (as of 2019-10-29) of the Copenhagen metro (L<wikipedia|https://en.wikipedia.org/wiki/Copenhagen_metro>)
 
 =back
 
